==> apache-camel-3.0.0-RC1-src.zip: apache-camel-3.0.0-RC1/core/camel-core/src/test/java/org/apache/camel/processor/DefaultErrorHandlerCatchThrowableTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.CamelExecutionException;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

public class DefaultErrorHandlerCatchThrowableTest extends ContextTestSupport {

    @Test
    public void testDefaultErrorHandlerCatchThrowable() throws Exception {
        try {
            template.sendBody("direct:start", "Hello World");
            fail("Should have thrown exception");
        } catch (CamelExecutionException e) {
            assertEquals("Hello World", e.getExchange().getIn().getBody());
            NoSuchMethodError cause = assertIsInstanceOf(NoSuchMethodError.class, e.getCause());
            assertEquals("This is an Error not an Exception", cause.getMessage());
        }
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                final String exceptionString = "This is an Error not an Exception";

                from("direct:start").process(new Processor() {
                    public void process(Exchange exchange) throws Exception {
                        throw new NoSuchMethodError(exceptionString);
                    }
                });
            }
        };
    }
}

==> apache-camel-4.0.0-RC1-src.zip: apache-camel-4.0.0-RC1/core/camel-core/src/test/java/org/apache/camel/processor/DefaultErrorHandlerCatchThrowableTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.CamelExecutionException;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.fail;

public class DefaultErrorHandlerCatchThrowableTest extends ContextTestSupport {

    @Test
    public void testDefaultErrorHandlerCatchThrowable() throws Exception {
        try {
            template.sendBody("direct:start", "Hello World");
            fail("Should have thrown exception");
        } catch (CamelExecutionException e) {
            assertEquals("Hello World", e.getExchange().getIn().getBody());
            NoSuchMethodError cause = assertIsInstanceOf(NoSuchMethodError.class, e.getCause());
            assertEquals("This is an Error not an Exception", cause.getMessage());
        }
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                final String exceptionString = "This is an Error not an Exception";

                from("direct:start").process(new Processor() {
                    public void process(Exchange exchange) throws Exception {
                        throw new NoSuchMethodError(exceptionString);
                    }
                });
            }
        };
    }
}
